@@ -216,11 +216,11 @@ static u_int32_t mspectou32(char *mstr) {
   if(strtou32(&num, mstr)) mask = num ? ~0 << (32 - num) : num;
   else if(inet_aton(mstr, &s)) {
     mask = ntohl(s.s_addr);
-    for(num = mask; num & 1; num >>= 1);
-    if(num == 0 || mask == 0) mask = ~mask;
-    else {
-      for(num = ~mask; num & 1; num >>= 1);
+    for(num = ~mask; num & 1; num >>= 1);
+    if(num) {
+      for(num = mask; num & 1; num >>= 1);
       if(num) panic("invalid mask 0x%08x from \"%s\"", mask, mstr);
+      mask = ~mask;
     }
   } else panic("unable to parse \"%s\"", mstr);
   return(mask);
@@ -258,7 +258,11 @@ static int strtou32(u_int32_t *num, char *istr) {
 static int rangetoaml(u_int32_t low, u_int32_t high) {
   u_int32_t i, j, lxh;
 
-  if(low > high) low ^= high ^= low ^= high;
+  if(low > high) {
+  	i = low;
+  	low = high;
+  	high = i;
+  }
   for(lxh = i = low ^ high; i & 1; i >>= 1);
   if(i == 0 && (low | lxh) == high) addtoaml(low, ~(high - low));
   else {
